@@ -30,13 +30,7 @@ from indico_install.cluster_manager import ClusterManager
 )
 @options_wrapper()
 def encode(
-    ctx,
-    value=None,
-    from_key=None,
-    save_key=None,
-    from_file=None,
-    stdout=True,
-    **kwargs,
+    ctx, value=None, from_key=None, save_key=None, from_file=None, stdout=True, **kwargs
 ):
     """
     Base64 encode a string from a provided source
@@ -94,13 +88,7 @@ def encode(
 )
 @options_wrapper()
 def decode(
-    ctx,
-    value=None,
-    from_key=None,
-    save_key=None,
-    save_file=None,
-    stdout=True,
-    **kwargs,
+    ctx, value=None, from_key=None, save_key=None, save_file=None, stdout=True, **kwargs
 ):
     """
     Decode a base64-encoded string from a provided source
