@@ -102,7 +102,8 @@ def create(ctx, eksctl_file=None, enable_cloudwatch=False):
                         "values": {
                             "annotations": {
                                 "service.beta.kubernetes.io/aws-load-balancer-internal": "0.0.0.0/0"
-                            }
+                            },
+                            "externalTrafficPolicy": "Cluster",
                         }
                     }
                 },
