@@ -64,17 +64,20 @@ def push_all(ctx, *, services_yaml, cluster, yes, deployment_root, forwarded=Tru
     # Frontend
     ctx.invoke(
         render,
-        service="app-edge-nginx-conf",
+        services=["app-edge-nginx-conf"],
         deployment_root=deployment_root,
         cluster=cluster,
         cluster_manager=ctx.obj["TRACKER"],
         services_yaml=services_yaml,
     )
     ctx.invoke(
-        apply, service="app-edge-nginx-conf", deployment_root=deployment_root, yes=yes
+        apply,
+        services=["app-edge-nginx-conf"],
+        deployment_root=deployment_root,
+        yes=yes,
     )
     ctx.obj["TRACKER"].update(frontend=get_deployed_frontend())
-    ctx.invoke(restart, service="app-edge")
+    ctx.invoke(restart, services=["app-edge"])
     secho("Done pushing changes", fg="green")
 
 
@@ -199,5 +202,5 @@ def push_client(ctx, fehash):
         )
         secho(run_cmd(command, silent=True))
         ctx.obj["TRACKER"].update(frontend=fehash)
-        ctx.invoke(restart, service="app-edge")
+        ctx.invoke(restart, services=["app-edge"])
         secho("Done pushing changes", fg="green")
