@@ -1,4 +1,3 @@
-import json
 from pathlib import Path
 
 import click
@@ -90,34 +89,19 @@ def show_current(ctx):
 @updraft.command("edit")
 @click.pass_context
 @click.option(
-    "-I", "--interactive", is_flag=True, help=f"Open configmap in your editor"
+    "-I", "--interactive", is_flag=True, help="[Deprecated] Open configmap in an editor"
 )
-@click.option("-v", "--version", help=f"Update to new updraft version")
+@click.option("-v", "--version", help="Update to new updraft version")
 @click.option(
-    "--force", is_flag=True, help=f"Render and apply even if there are no changes"
+    "--force", is_flag=True, help="Render and apply even if there are no changes"
 )
-@click.option("--patch-file", type=click.File("r"), help="JSON-formatted patch file")
-@click.argument("patch", required=False)
+@click.option("--patch-file", type=click.File("r"), help="YAML-formatted patch file")
 @options_wrapper()
-def edit_configmap(
-    ctx,
-    *,
-    interactive,
-    patch,
-    force,
-    patch_file,
-    version,
-    yes,
-    deployment_root,
-    **kwargs,
-):
+def edit_configmap(ctx, *, force, patch_file, version, yes, deployment_root, **kwargs):
     """
-    Edit configmap with some patch, or interactively.
+    Edit configmap interactively or through a patch file.
     Only allows editing of the main cluster config portion
 
-    PATCH - if not interactive, and no patch-file is provided,
-    pass in a json string to patch the configmap with
-
     ex: indico updraft edit '{"apiDomain": "api-foo.indico.io"}'
     """
     cluster_manager = ClusterManager()
@@ -129,9 +113,12 @@ def edit_configmap(
         return
     changes = None
     replace = False
+    interactive = True
 
-    if any([interactive, patch_file, patch]):
-        replace = True
+    if any([patch_file, version, force]):
+        interactive = False
+
+    if interactive or patch_file:
         cluster_manager.save(backup=True)
 
     service_state = cluster_manager.clean_services()
@@ -140,15 +127,15 @@ def edit_configmap(
             yaml.dump(cluster_manager.cluster_config, default_flow_style=False)
         )
         changes = yaml.safe_load(changes or "")
+        replace = True
     elif patch_file:
-        changes = json.load(patch_file)
-    elif patch:
-        changes = json.loads(patch)
+        with open(patch_file, "r") as f:
+            changes = yaml.safe_load(f)
 
     version = string_to_tag(version) if version else None
     if force or changes or (version and version != cluster_manager.indico_version):
         if force or version:
-            click.secho(f"This will override custom images!", fg="yellow")
+            click.secho("This will override custom images!", fg="yellow")
         cluster_manager.edit_cluster_config(
             changes=merge_dicts(changes or {}, service_state),
             version=version,
@@ -156,7 +143,7 @@ def edit_configmap(
         )
     else:
         click.secho(
-            f"No changes or new version provided. Use --force if required", fg="yellow"
+            "No changes or new version provided. Use --force if required", fg="yellow"
         )
         return
 
@@ -172,7 +159,7 @@ def edit_configmap(
 
 @updraft.command("restore")
 @click.pass_context
-@click.option("--keep-images", is_flag=True, help=f"Keep the current deployed images")
+@click.option("--keep-images", is_flag=True, help="Keep the current deployed images")
 @options_wrapper()
 def restore_version(ctx, deployment_root, yes, keep_images=False):
     """
